@@ -85,6 +85,10 @@ class Parser(icli.ArgumentParser):
         print('w - who is logged in')
         print()
 
+    def handle_interactive_exception(self):
+        import traceback
+        err(traceback.format_exc())
+
 
 def append_registry_cli(root_sp):
     ap = root_sp.add_parser('registry', help='registry commands')
@@ -185,10 +189,10 @@ def append_action_cli(root_sp):
 
 
 def append_broker_cli(root_sp):
-    ap = root_sp.add_parser('broker', help='ELBUS broker commands')
+    ap = root_sp.add_parser('broker', help='bus broker commands')
     sp = ap.add_subparsers(dest='_subc', help='sub command')
 
-    sp.add_parser('client.list', help='list registered ELBUS clients')
+    sp.add_parser('client.list', help='list registered bus clients')
     sp.add_parser('test', help='test broker')
     sp.add_parser('info', help='broker info')
     sp.add_parser('stats', help='broker stats')
@@ -759,6 +763,13 @@ def append_node_cli(root_sp):
         metavar='SVC').completer = ComplSvc('repl')
 
 
+def append_spoint_cli(root_sp):
+    ap = root_sp.add_parser('spoint', help='spoint commands')
+    sp = ap.add_subparsers(dest='_subc', help='sub command')
+
+    p = sp.add_parser('list', help='list nodes')
+
+
 def append_venv_cli(root_sp):
     ap = root_sp.add_parser('venv', help='manage Python venv')
     sp = ap.add_subparsers(dest='_subc', help='sub command')
@@ -844,7 +855,10 @@ def append_cloud_cli(root_sp):
                    help=f'test deployment config and exit')
 
     p = sp.add_parser('update', help='update cloud nodes')
-    p.add_argument('nodes', metavar='NODE', nargs='*').completer = ComplNode()
+    p.add_argument('nodes',
+                   metavar='NODE',
+                   nargs='*',
+                   help="Node name or node/spoint").completer = ComplNode()
     p.add_argument('--check-timeout',
                    help='Max node update duration (default: 120 sec)',
                    default=120,
@@ -973,6 +987,7 @@ def init_ap():
     append_lvar_cli(sp)
     append_log_cli(sp)
     append_node_cli(sp)
+    append_spoint_cli(sp)
     append_registry_cli(sp)
     append_server_cli(sp)
     append_user_cli(sp)
@@ -985,6 +1000,11 @@ def init_ap():
     append_svc_cli(sp)
     sp.add_parser('test', help='core test/info')
 
+    p = sp.add_parser('dump', help='dump node info')
+    p.add_argument('-s',
+                   action='store_true',
+                   help='create an encrypted service request')
+
     p = sp.add_parser('edit', help='edit the configuration keys and xc files')
     p.add_argument(
         'fname',
