@@ -1,6 +1,7 @@
 import os
 import sys
 import time
+from datetime import datetime
 from functools import partial
 
 import elbus
@@ -52,6 +53,16 @@ class CLI:
         data = call_rpc('test')
         print_result(data, need_header=False, name_value=True)
 
+    def dump(self, s=False):
+        args = ''
+        args = ''
+        if current_command.debug:
+            args += ' --verbose '
+        args += f'node dump --connection-path "{common.bus_path}"'
+        if s:
+            args += ' -s'
+        exec_cmd('eva-cloud-manager', args)
+
     def save(self):
         call_rpc('save')
         ok()
@@ -93,7 +104,7 @@ class CLI:
         if current_command.debug:
             args += ' --verbose '
         args += (f'cloud deploy --timeout {current_command.timeout}'
-                 f' --connection-path "{common.elbus_path}" "{file}"')
+                 f' --connection-path "{common.bus_path}" "{file}"')
         if config_var:
             for c in config_var:
                 args += f' --config-var "{c}"'
@@ -108,7 +119,7 @@ class CLI:
         if current_command.debug:
             args += ' --verbose '
         args += (f'cloud undeploy --timeout {current_command.timeout}'
-                 f' --connection-path "{common.elbus_path}" "{file}"')
+                 f' --connection-path "{common.bus_path}" "{file}"')
         if config_var:
             for c in config_var:
                 args += f' --config-var "{c}"'
@@ -125,7 +136,7 @@ class CLI:
         if current_command.debug:
             args += ' --verbose '
         args += (f'cloud update --timeout {current_command.timeout}'
-                 f' --connection-path "{common.elbus_path}"'
+                 f' --connection-path "{common.bus_path}"'
                  f' --check-timeout "{check_timeout}"')
         args += ' ' + ' '.join([f'"{n}"' for n in nodes])
         if all:
@@ -172,7 +183,7 @@ class CLI:
         try:
             data = call_rpc('test')
             system_name = data.get('system_name', '')
-            yedb_socket = f'elbus://{common.elbus_path}:eva.registry'
+            yedb_socket = f'elbus://{common.bus_path}:eva.registry'
             os.system(f'env "YEDB_PS=registry:{system_name}" "{cmd}" '
                       f'"{yedb_socket}"{args}')
         except:
@@ -600,7 +611,11 @@ class CLI:
             print_result(data)
         else:
             print_result(
-                [d for d in data['clients'] if d['name'] != common.elbus_name])
+                [d for d in data['clients'] if d['name'] != common.bus_name],
+                cols=[
+                    'name', 'kind|n=type', 'source', 'port', 'r_frames',
+                    'r_bytes', 'w_frames', 'w_bytes', 'queue', 'instances|n=ins'
+                ])
 
     def action_exec(self, i, status, value, priority, wait):
         params = dict(i=i, wait=wait)
@@ -690,7 +705,11 @@ class CLI:
                     elapsed = '{:.6f}'.format(max(times) - min(times))
                 else:
                     elapsed = ''
+                t = r.get('time', {}).get('accepted')
+                if t:
+                    t = datetime.fromtimestamp(t, common.TZ).isoformat()
                 data.append({
+                    'time': t,
                     'uuid': str(uuid.UUID(bytes=r['uuid'])),
                     'oid': r['oid'],
                     'status': r['status'],
@@ -825,6 +844,10 @@ class CLI:
         print(f'{len(nodes)} node(s) undeployed')
         print()
 
+    def spoint_list(self):
+        data = call_rpc('spoint.list')
+        print_result(data, cols=['name', 'source', 'port', 'version', 'build'])
+
     def item_list(self, i, n=None):
         data = call_rpc(
             'item.list',
@@ -832,8 +855,8 @@ class CLI:
         )
         print_result(data,
                      cols=[
-                         'oid', 'status', 'value', 't|n=set time|f=time',
-                         'node', 'connected', 'enabled'
+                         'oid', 'status', 'value|l=20|n=value',
+                         't|n=set time|f=time', 'node', 'connected', 'enabled'
                      ])
 
     def item_announce(self, i, n=None):
@@ -931,7 +954,7 @@ class CLI:
         )
         print_result(data,
                      cols=[
-                         'oid', 'status', 'value', 'ieid',
+                         'oid', 'status', 'value|l=20|n=value', 'ieid',
                          't|n=set time|f=time', 'node', 'connected', 'act'
                      ])
 
