@@ -16,10 +16,12 @@ DEFAULT_AUTH_SERVICE = 'eva.aaa.localauth'
 
 
 def call_rpc(method, params=None, target='eva.core'):
+    name = f'{common.bus_name}.{common.bus_conn_no}'
+    common.bus_conn_no += 1
     if current_command.debug:
-        debug(f'calling ELBUS {common.elbus_path} as {common.elbus_name}')
+        debug(f'calling bus cli {common.bus_path} as {name}')
     if common.bus is None or not common.bus.is_connected():
-        common.bus = elbus.client.Client(common.elbus_path, common.elbus_name)
+        common.bus = elbus.client.Client(common.bus_path, name)
         common.bus.connect()
         common.rpc = elbus.rpc.Rpc(common.bus)
     if current_command.debug:
