@@ -3,8 +3,9 @@ from types import SimpleNamespace
 import pytz
 
 common = SimpleNamespace(dir_eva=None,
-                         elbus_path=None,
-                         elbus_name=None,
+                         bus_path=None,
+                         bus_name=None,
+                         bus_conn_no=0,
                          bus=None,
                          rpc=None,
                          cli=None,
