@@ -296,6 +296,13 @@ def print_result(data, need_header=True, name_value=False, cols=None):
                                             val = int(val)
                             except:
                                 pass
+                        if val is not None:
+                            val = str(val)
+                            max_len = rules.get('l')
+                            if max_len is not None:
+                                max_len = int(max_len) - 3
+                                if len(val) > max_len:
+                                    val = val[:max_len] + '...'
                         od[rules.get('n', c)] = val
                     formatted_data.append(od)
                 header, rows = format_table(formatted_data,
